Skip to contents

Generates an interactive plot with average speed of bases going through the pore per hour, filtered by pass/fail status.

Usage

plot_average_speed(seq_summary)

Arguments

seq_summary

A dataframe containing the sequencing summary

Value

plotly object

Examples

if (FALSE) { # \dontrun{
plot_average_speed(sample_data)
} # }