Generates an interactive plot with number of reads of each length in bases.
Two vertical lines represent the mean read length and the N50 value
calculated with calculate_n50.
Generates an interactive plot with number of reads of each length in bases.
Two vertical lines represent the mean read length and the N50 value
calculated with calculate_n50.